@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::CheckIssues;
-# git description: v0.005-1-gf515c93
-$Dist::Zilla::Plugin::CheckIssues::VERSION = '0.006';
+# git description: v0.006-1-ge46957a
+$Dist::Zilla::Plugin::CheckIssues::VERSION = '0.007';
 # ABSTRACT: Retrieve count of outstanding RT and github issues for your distribution
 # KEYWORDS: plugin bugs issues rt github
 # vim: set ts=8 sw=4 tw=78 et :
@@ -141,7 +141,7 @@ sub _rt_data_for_dist
     my $json = $self->_rt_data_raw;
     return if not $json;
 
-    require JSON::MaybeXS;
+    require JSON::MaybeXS; JSON::MaybeXS->VERSION('1.001000');
     my $all_data = JSON::MaybeXS->new(utf8 => 0)->decode($json);
     return if not $all_data->{$dist_name};
 
@@ -171,7 +171,7 @@ sub _github_issue_count
     my $json = $self->_fetch('https://api.github.com/repos/' . $owner_name . '/' . $repo_name);
     $self->log('could not fetch github data?'), return if not $json;
 
-    require JSON::MaybeXS;
+    require JSON::MaybeXS; JSON::MaybeXS->VERSION('1.001000');
     my $data = JSON::MaybeXS->new(utf8 => 0)->decode($json);
     $data->{open_issues_count};
 }
@@ -209,7 +209,7 @@ Dist::Zilla::Plugin::CheckIssues - Retrieve count of outstanding RT and github i
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
